flot

package module
v0.0.0-...-3218524 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2025 License: Apache-2.0 Imports: 23 Imported by: 0

README

Flot Preview

Flot

Flot is an open source Make.com alternative, a workflow automation tool that is just as easy to use as it is deployed.

Features

TODO: Add features

Getting Started

TODO: Add getting started

Contributing

TODO: Add contributing

Troubleshooting
SSH Agent Connection Error in Devcontainer

If you encounter this error when using Git in the devcontainer:

This means the SSH agent service isn't running on your Windows machine. To fix this:

  1. Start the SSH agent service:

    # Run PowerShell as Administrator
    Set-Service ssh-agent -StartupType Automatic
    Start-Service ssh-agent
    
  2. Add your SSH key to the agent:

    ssh-add $HOME/.ssh/id_rsa  # or path to your specific key
    
  3. Verify the key was added:

    ssh-add -l
    
  4. Rebuild your devcontainer

If you're still having issues:

  • Ensure your SSH keys exist in your local ~/.ssh directory
  • Verify your SSH key is added to your GitHub account
  • Check the permissions of your SSH files with ls -la ~/.ssh in the container

License

Flot is licensed under the Apache License, Version 2.0.

Documentation

Index

Constants

This section is empty.

Variables

var Version = "(untracked)"

Functions

This section is empty.

Types

type Config

type Config struct {
	DefaultDev           bool
	DefaultDataDir       string
	DefaultEncryptionKey string
	NatsURL              string
	Db                   *gorm.DB
	Ctx                  context.Context
}

type Flot

type Flot struct {
	RootCmd *cobra.Command
	// contains filtered or unexported fields
}

func New

func New() *Flot

func NewWithConfig

func NewWithConfig(config Config) *Flot

func (*Flot) Execute

func (f *Flot) Execute() (err error)

func (*Flot) Start

func (f *Flot) Start() error

type NatsWriter

type NatsWriter struct {
	// contains filtered or unexported fields
}

func (NatsWriter) Write

func (w NatsWriter) Write(p []byte) (n int, err error)

Directories

Path Synopsis
cmd
app
worker command
examples
base command
internal
kv

Jump to